@@ -554,10 +554,13 @@ class MyWhatify:
     @classmethod
     def get_data_file(cls, data_name='car_sdk_demo.csv'):
         with allure.step('getting csv from data file for data_name: ' + str(data_name)):
-            script_dir = os.path.dirname(__file__)
-            path = os.path.join(script_dir, 'data_source/')
+            # script_dir = os.getcwd()
+            # script_dir = os.path.dirname(__file__)
+            # path = os.path.join(script_dir, 'data_source/', data_name)
+            path = os.path.join(os.getcwd(), 'data_source/', data_name)
+            # path = os.path.join('/home/moshe/Downloads/work/Whatify_Toolkit/toolkit_w', 'data_source/', data_name)
             # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
-        return pd.read_csv(path + data_name)
+        return pd.read_csv(path)
 
     @classmethod
     def get_created_data_file(cls, data_name='temp.csv'):
